kraken API
==========

.. module:: kraken

Kraken provides routines which are usable by third party tools. In general
you can expect function in the ``kraken`` package to remain stable. We will try
to keep these backward compatible, but as kraken is still in an early
development stage and the API is still quite rudimentary nothing can be
garantueed.

kraken.binarization module
--------------------------

.. automodule:: kraken.binarization
    :members:
    :show-inheritance:

kraken.serialization module
---------------------------

.. automodule:: kraken.serialization
    :members:
    :show-inheritance:

kraken.pageseg module
---------------------

.. automodule:: kraken.pageseg
    :members:
    :show-inheritance:

kraken.rpred module
-------------------

.. automodule:: kraken.rpred
    :members:
    :show-inheritance:

kraken.transcribe module
------------------------

.. automodule:: kraken.transcribe
    :members:
    :show-inheritance:

kraken.linegen module
---------------------

.. automodule:: kraken.linegen
    :members:
    :show-inheritance:

kraken.lib.models module
------------------------

.. automodule:: kraken.lib.models
    :members:
    :show-inheritance:

kraken.lib.vgsl module
----------------------

.. automodule:: kraken.lib.vgsl
    :members:
    :show-inheritance:

kraken.lib.codec
----------------

.. automodule:: kraken.lib.codec
    :members:
    :show-inheritance:

kraken.lib.train module
-----------------------

.. automodule:: kraken.lib.train
    :members:
    :show-inheritance:

kraken.lib.dataset module
-------------------------

.. automodule:: kraken.lib.dataset
    :members:
    :show-inheritance:

kraken.lib.ctc_decoder
----------------------

.. automodule:: kraken.lib.ctc_decoder
    :members:
    :show-inheritance:
